@@ -12,6 +12,8 @@ __all__ = [
     "erf",
     "erfc",
     "erf_inv",
+    "eq",
+    "igamma",
     "select",
 ]
 
@@ -30,4 +32,6 @@ digamma = quaxify(lax.digamma)
 erf = quaxify(lax.erf)
 erfc = quaxify(lax.erfc)
 erf_inv = quaxify(lax.erf_inv)
+eq = quaxify(lax.eq)
+igamma = quaxify(lax.igamma)
 select = quaxify(lax.select)
