@@ -9,9 +9,9 @@ from jax._src.numpy.setops import (
     _UniqueCountsResult,
     _UniqueInverseResult,
 )
-from jax.experimental.array_api._data_type_functions import FInfo, IInfo
 
 import quaxed.array_api as xp
+from quaxed.array_api._data_type_functions import FInfo, IInfo
 
 from ..myarray import MyArray
 
@@ -225,7 +225,7 @@ def test_finfo():
     expected = jax_xp.finfo(jnp.float32)
 
     assert isinstance(got, FInfo)
-    for attr in FInfo.__slots__:
+    for attr in ("bits", "eps", "max", "min", "smallest_normal", "dtype"):
         assert getattr(got, attr) == getattr(expected, attr)
 
 
@@ -235,7 +235,7 @@ def test_iinfo():
     expected = jax_xp.iinfo(jnp.int32)
 
     assert isinstance(got, IInfo)
-    for attr in IInfo.__slots__:
+    for attr in ("kind", "bits", "min", "max", "dtype"):
         assert getattr(got, attr) == getattr(expected, attr)
 
 
@@ -1180,6 +1180,42 @@ def test_sort():
 # Statistical functions
 
 
+def test_cumulative_sum():
+    """Test `cumulative_sum`."""
+    x = MyArray(xp.asarray([1, 2, 3], dtype=float))
+
+    # No arguments
+    got = xp.cumulative_sum(x)
+    expected = MyArray(xp.asarray([1, 3, 6], dtype=float))
+
+    assert isinstance(got, MyArray)
+    assert jnp.array_equal(got.array, expected.array)
+
+    # axis
+    got = xp.cumulative_sum(x, axis=0)
+    expected = MyArray(xp.asarray([1, 3, 6], dtype=float))
+
+    assert isinstance(got, MyArray)
+    assert jnp.array_equal(got.array, expected.array)
+
+    with pytest.raises(ValueError, match="axis 1"):
+        _ = xp.cumulative_sum(x, axis=1)
+
+    # dtype
+    got = xp.cumulative_sum(x, dtype=int)
+    expected = MyArray(xp.asarray([1, 3, 6], dtype=int))
+
+    assert isinstance(got, MyArray)
+    assert jnp.array_equal(got.array, expected.array)
+
+    # initial
+    got = xp.cumulative_sum(x, include_initial=True)
+    expected = MyArray(xp.asarray([0, 1, 3, 6]))
+
+    assert isinstance(got, MyArray)
+    assert jnp.array_equal(got.array, expected.array)
+
+
 @pytest.mark.skip("TODO")
 def test_max():
     """Test `max`."""
