@@ -264,16 +264,18 @@ def _complex_p(x: MyArray, y: MyArray) -> MyArray:
 def _concatenate_p(
     operand0: MyArray,
     *operands: MyArray,
-    dimension: Any,
+    **kwargs: Any,
 ) -> MyArray:
     return MyArray(
-        lax.concatenate(
-            [operand0.array] + [op.array for op in operands],
-            dimension=dimension,
-        ),
+        lax.concatenate([operand0.array] + [op.array for op in operands], **kwargs)
     )
 
 
+@register(lax.concatenate_p)
+def _concatenate_p(operand0: ArrayLike, operand1: MyArray, /, **kwargs: Any) -> MyArray:
+    return MyArray(lax.concatenate_p.bind(operand0, operand1.array, **kwargs))
+
+
 # ==============================================================================
 
 
@@ -303,14 +305,11 @@ def _conv_general_dilated_p() -> MyArray:
 
 
 @register(lax.convert_element_type_p)
-def _convert_element_type_p(
-    operand: MyArray,
-    *,
-    new_dtype: Any,
-    weak_type: Any,
-) -> MyArray:
-    del weak_type
-    return replace(operand, array=lax.convert_element_type(operand.array, new_dtype))
+def _convert_element_type_p(operand: MyArray, **kwargs: Any) -> MyArray:
+    return replace(
+        operand,
+        array=lax.convert_element_type_p.bind(operand.array, **kwargs),
+    )
 
 
 # ==============================================================================
@@ -396,8 +395,8 @@ def _cumsum_p(operand: MyArray, *, axis: Any, reverse: Any) -> MyArray:
 
 
 @register(lax.device_put_p)
-def _device_put_p(x: MyArray, *, device: Any, src: Any) -> MyArray:
-    return replace(x, array=jax.device_put(x.array, device=device, src=src))
+def _device_put_p(x: MyArray, **kwargs: Any) -> MyArray:
+    return replace(x, array=jax.device_put(x.array, **kwargs))
 
 
 # ==============================================================================
